require "rails_helper"

RSpec.describe Form::Sales::Questions::BuyerInterview, type: :model do
  subject(:question) { described_class.new(question_id, question_definition, page, joint_purchase: false) }

  let(:question_id) { nil }
  let(:question_definition) { nil }
  let(:page) { instance_double(Form::Page, subsection: instance_double(Form::Subsection, form: instance_double(Form, start_date: Time.zone.local(2023, 4, 1)))) }

  it "has correct page" do
    expect(question.page).to eq(page)
  end

  it "has the correct id" do
    expect(question.id).to eq("noint")
  end

  it "has the correct header" do
    expect(question.header).to eq("Was the buyer interviewed for any of the answers you will provide on this log?")
  end

  it "has the correct check_answer_label" do
    expect(question.check_answer_label).to eq("Buyer interviewed in person?")
  end

  it "has the correct type" do
    expect(question.type).to eq("radio")
  end

  it "is not marked as derived" do
    expect(question.derived?(nil)).to be false
  end

  it "has the correct hint" do
    expect(question.hint_text).to eq("You should still try to answer all questions even if the buyer wasn’t interviewed in person")
  end

  it "has the correct answer_options" do
    expect(question.answer_options).to eq({
      "2" => { "value" => "Yes" },
      "1" => { "value" => "No" },
    })
  end

  context "with joint purchase" do
    subject(:question) { described_class.new(question_id, question_definition, page, joint_purchase: true) }

    it "has the correct header" do
      expect(question.header).to eq("Were the buyers interviewed for any of the answers you will provide on this log?")
    end

    it "has the correct hint_text" do
      expect(question.hint_text).to eq("You should still try to answer all questions even if the buyers weren’t interviewed in person")
    end

    it "has the correct check_answer_label" do
      expect(question.check_answer_label).to eq("Buyers interviewed in person?")
    end
  end
end
